/*
 * Licensed to the University Corporation for Advanced Internet Development, 
 * Inc. (UCAID) under one or more contributor license agreements.  See the 
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache 
 * License, Version 2.0 (the "License"); you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.internet2.middleware.shibboleth.common.attribute.resolver.provider.dataConnector;

import edu.vt.middleware.ldap.Ldap;
import edu.vt.middleware.ldap.pool.LdapFactory;
import edu.vt.middleware.ldap.pool.LdapPoolConfig;

/**
 * Ldap pool strategy that does no pooling. 
 */
public class LdapPoolEmptyStrategy implements LdapPoolStrategy {

    /** Factory for making ldap objects. */
    private LdapFactory<Ldap> ldapFactory;

    /**
     * Default constructor.
     */
    public LdapPoolEmptyStrategy() {}

    /** {@inheritDoc} */
    public void setLdapPoolConfig(LdapPoolConfig config) {}

    /** {@inheritDoc} */
    public void setLdapFactory(LdapFactory<Ldap> factory) {
        ldapFactory = factory;
    }

    /** {@inheritDoc} */
    public void setBlockWhenEmpty(boolean block) {}

    /** {@inheritDoc} */
    public void initialize() {}

    /** {@inheritDoc} */
    public Ldap checkOut() throws Exception {
        return ldapFactory.create();
    }

    /** {@inheritDoc} */
    public void checkIn(Ldap l) throws Exception {
        ldapFactory.destroy(l);
    }
}
